// A trigger assembly. Contains a base box and a moving part. Regular and deep
// versions of each. In practice, regular box and deep moving part work
// together nicely. 

// Use a part of paperclip for the axle. For contacts, glue 16AWG stranded
// wire to the back of the box below the wire openings and glue a piece of thin
// metal (1mm or so) to the bottom of the moving trigger. This gives the best
// movement and contact.

// Part of the components library.

// By Nenad Rijavec
// Feel free to use, share, modify, etc. as you see fit.
use <plib/cylinder_wedge.scad>

h = 12 ; // thickness of the trigger
do_build = 1 ;
do_regular = 1 ;
do_deep = 0 ;

module trigger_moving_slab( h )
{
	hull() {
		translate( [ 0, 5, 0 ] )
			cube( [ 1, 50, h ], center=true ) ;
		translate( [ -3, 0, 0 ] )
		rotate( [ 0, 0, -16 ] ) 
		translate( [ -2, 4, 0 ] )
		cube( [ 1, 50, h ], center=true ) ;
		translate( [ 9, 1, 0 ] )
		rotate( [ -90, 0, -10 ] ) 
		translate( [ -4, 0, -25 ] )
		intersection() {
			cylinder( 50, d=30, $fn=100 ) ;
			translate( [ -20, -h/2, -10 ] )
				cube( [ 9, h, 100 ] ) ;
		}
		translate( [ 0, 20, -h/2 ] )
		cylinder_wedge( 80, 30, 253, 17 )
			cylinder( h, d=85, $fn=100 ) ;
    	}
	translate( [ 0, 20, -h/2 ] )
	cylinder_wedge( 80, 30, 266.0, 4.0 )
		cylinder( h, d=90, $fn=100 ) ;
			
}

module trigger_moving( h ) 
{
	// hollow body
	difference() {
		trigger_moving_slab( h ) ;
		union() {
			translate( [ 0.5, 0.0, 0 ] ) 
			scale( [ 0.9, 0.95, 0.7 ] )
				trigger_moving_slab( h ) ;
			translate( [ 0, 25, -1-h/2 ] )
				cylinder( h+2, d=2, $fn=100 ) ;
			translate( [ 0, -20, -1-h/2 ] )
				cylinder( h+2, d=2, $fn=100 ) ;
			translate( [ -1, -25, h/2-2 ] )
			cube( [ 2, 5, 3 ] ) ;
			translate( [ -1, -25, -h/2-1 ] )
			cube( [ 2, 5, 3 ] ) ;
		}
	}
	//spring holder, intersection to make flush with base
	intersection() {
		rotate( [ 0, 90, -10 ] )
		translate( [ 0, 0, -9 ] )
		difference() {
			cylinder( 22, d=12, $fn=100 ) ;
			translate( [ 0, 0, 1 ] )
				cylinder( 25, d=8, $fn=100 ) ;
		}
		translate( [ -10.1, 0, 0 ] )
		rotate( [ 0, 0, -4 ] )
			cube( [ 24, 100, 100 ], center = true ) ;
	}
	// body base
	difference() {
		translate( [ 2, 1.75, 0 ] )
		rotate( [ 0, 0, -2.25 ] )
			cube( [ 1, 53.5, h ], center=true ) ;
		rotate( [ 0, 90, -10 ] )
		translate( [ 0, 0, -14 ] )
			cylinder( 25, d=8, $fn=100 ) ;
	}
	translate( [ 0, -23, 0 ] )
	rotate( [ 0, 0, -2 ] )
		cube( [ 3, 3.5, h-4 ], center=true ) ;
}

module trigger_housing( h )
{
	difference()
	{
		cube( [ 15, 62, h+6 ] ) ;
		union() {
			translate( [ -2, 2, 2 ] )
				cube( [ 15, 58, h+2 ] ) ;
			translate( [ 3, 53, -1 ] )
				cylinder( h+8, d=2, $fn=100 ) ;
			translate( [ 5, 10, h/2-2 ] )
			rotate( [ 0, 90, 0 ] ) cylinder( 20, d=3, $fn=100 ) ;
			translate( [ 5, 10, h/2+8 ] )
			rotate( [ 0, 90, 0 ] ) cylinder( 20, d=3, $fn=100 ) ;
			translate( [ 5, 10, h/2-2 ] )
			rotate( [ 90, 0, 0 ] ) cylinder( 20, d=3, $fn=100 ) ;
			translate( [ 5, 10, h/2+8 ] )
			rotate( [ 90, 0, 0 ] ) cylinder( 20, d=3, $fn=100 ) ;
		}
	}

	translate( [ -5, 53, 0 ] )
	difference() {
		cylinder_wedge( 150, 30, 285, 5 )
		cylinder( h+4, d=107, $fn=100 ) ;
		translate( [ 0, 0, -1 ] )
		cylinder_wedge( 150, 30, 276, 28 )
		cylinder( h+6, d=105, $fn=100 ) ;
	}
	cube( [ 2, 4, h+6 ] ) ;
	intersection() {
		translate( [ 25, 18, h/2+3.0 ] )
		rotate( [ 0, 90, 0 ] )
		translate( [ 0, 10, -15 ] )
			cylinder( 5, d=4, $fn=100 ) ;
		translate( [ 4, 7, 0 ] )
		cube ( [ 20, 40, h+3 ] ) ;
	}
}

module trigger_moving_slab_deep( h )
{
	hull() {
		translate( [ 0, 5, 0 ] )
			cube( [ 1, 50, h ], center=true ) ;
		translate( [ -10, 0, 0 ] )
		rotate( [ 0, 0, -20 ] ) 
		translate( [ 0, 5, 0 ] )
		cube( [ 10, 50, h ], center=true ) ;
		translate( [ 0, 0, 0 ] )
		rotate( [ -90, 0, -20 ] ) 
		translate( [ -4, 0, -25 ] )
		intersection() {
			cylinder( 50, d=30, $fn=100 ) ;
			translate( [ -20, -h/2, -10 ] )
				cube( [ 9, h, 100 ] ) ;
		}
		translate( [ 0, 20, -h/2 ] )
		cylinder_wedge( 80, 30, 241, 30 )
			cylinder( h, d=85, $fn=100 ) ;
    	}
	translate( [ 0, 20, -h/2 ] )
	cylinder_wedge( 80, 30, 265, 6 )
		cylinder( h, d=90, $fn=100 ) ;
			
}

module trigger_moving_deep( h ) 
{
	// hollow body
	difference() {
		trigger_moving_slab_deep( h ) ;
		union() {
			translate( [ 0.5, 0.4, 0 ] ) 
			scale( [ 0.9, 0.95, 0.7 ] )
				trigger_moving_slab_deep( h ) ;
			translate( [ 0, 25, -1-h/2 ] )
				cylinder( h+2, d=2, $fn=100 ) ;
			translate( [ 0, -20, -1-h/2 ] )
				cylinder( h+2, d=2, $fn=100 ) ;
			translate( [ -1, -25, h/2-2 ] )
			cube( [ 2, 5, 3 ] ) ;
			translate( [ -1, -25, -h/2-1 ] )
			cube( [ 2, 5, 3 ] ) ;
		}
	}
	//spring holder, intersection to make flush with base
	intersection() {
		rotate( [ 0, 90, -20 ] )
		translate( [ 0, 0, -17 ] )
		difference() {
			cylinder( 22, d=12, $fn=100 ) ;
			translate( [ 0, 0, 1 ] )
				cylinder( 25, d=8, $fn=100 ) ;
		}
		translate( [ -10.1, 0, 0 ] )
		rotate( [ 0, 0, -4 ] )
			cube( [ 27, 100, 100 ], center = true ) ;
	}
	// body base
	difference() {
		translate( [ 3, 0.75, 0 ] )
		rotate( [ 0, 0, -4 ] )
			cube( [ 1, 51.5, h ], center=true ) ;
		rotate( [ 0, 90, -20 ] )
		translate( [ 0, 0, -14 ] )
			cylinder( 25, d=8, $fn=100 ) ;
	}
}

module trigger_housing_deep( h )
{
	difference()
	{
		cube( [ 25, 62, h+6 ] ) ;
		union() {
			translate( [ -2, 2, 2 ] )
				cube( [ 25, 58, h+2 ] ) ;
			translate( [ 3, 53, -1 ] )
				cylinder( h+8, d=2, $fn=100 ) ;
			translate( [ 15, 10, h/2-2 ] )
			rotate( [ 0, 90, 0 ] ) cylinder( 20, d=3, $fn=100 ) ;
			translate( [ 15, 10, h/2+8 ] )
			rotate( [ 0, 90, 0 ] ) cylinder( 20, d=3, $fn=100 ) ;
			translate( [ 10, 10, h/2-2 ] )
			rotate( [ 90, 0, 0 ] ) cylinder( 20, d=3, $fn=100 ) ;
			translate( [ 10, 10, h/2+8 ] )
			rotate( [ 90, 0, 0 ] ) cylinder( 20, d=3, $fn=100 ) ;
		}
	}

	translate( [ -4, 53, 0 ] )
	difference() {
		cylinder_wedge( 150, 30, 288, 13 )
		cylinder( h+6, d=110, $fn=100 ) ;
		translate( [ 0, 0, -1 ] )
		cylinder_wedge( 150, 30, 286, 18 )
		cylinder( h+6, d=108, $fn=100 ) ;
	}
	cube( [ 2, 4, h+6 ] ) ;
	intersection() {
		translate( [ 35, 18, h/2+3.0 ] )
		rotate( [ 0, 90, 0 ] )
		translate( [ 0, 10, -15 ] )
			cylinder( 10, d=4, $fn=100 ) ;
		translate( [ 4, 7, 0 ] )
		cube ( [ 20, 40, h+3 ] ) ;
	}
}

if ( do_build ) {
	if ( do_regular ) {
		translate( [ 0, 0, 2.33 ] ) 
		rotate( [ 2.25, 0, 0 ] )
		rotate( [ 0, 90, 0 ] )
			trigger_moving( h ) ;
		translate( [ 10,-25, 14.90 ] )
		rotate( [ 0, 90, 0 ] )
			trigger_housing( h ) ;
	} 
	if ( do_deep ) {
		translate( [ do_regular * 50, 0, 0 ] ) 
		translate( [ 0, 0, 3.39 ] ) 
		rotate( [ 4, 0, 0 ] )
		rotate( [ 0, 90, 0 ] )
			trigger_moving_deep( h ) ;
		translate( [ do_regular * 50, 0, 0 ] ) 
		translate( [ 15,-25, 24.90 ] )
		rotate( [ 0, 90, 0 ] )
			trigger_housing_deep( h ) ;
	} 
} else {
//	translate( [ -30, 0, 30 ] ) trigger_moving(h ) ;
	if ( do_regular ) intersection() {
		union() {
			rotate( [ 0, 0, 3 ] )
			translate( [ 0, -25, 0 ] )
				trigger_moving( h ) ;
			translate( [ -3, -53, -h/2-3 ] ) trigger_housing( h ) ;
		}
		translate( [ -50, -70, -50 ] ) cube( [ 150, 150, 50 ] ) ;
	}
	if ( do_deep ) translate( [ do_regular * 40, 0, 0 ] ) intersection() {
		union() {
			rotate( [ 0, 0, 21 ] )
			translate( [ 0, -25, 0 ] )
				trigger_moving_deep( h ) ;
			translate( [ -3, -53, -h/2-3 ] )
				trigger_housing_deep( h ) ;
		}
		translate( [ -50, -70, -50 ] ) cube( [ 150, 150, 50 ] ) ;
	}
}
