// Carrier for the LCD display in two parts - base and cover. LCD fits
// tightly into the cover and will go in correctly only one way. The base
// also fits the cover only one way.

// Also contains knockout module to make space for the display housing in
// the body.

// By Nenad Rijavec
// Feel free to use, share, modify, etc. as you see fit.

lcd_pcb_l = 82 ;
lcd_pcb_w = 40 ;
plug_l = 0 ;
lcd_l = 73 ;
lcd_w = 25 ;
lcd_assembly_t = 18 ;
wall = 2 ;

module lcd_housing()
{
	// enclosure
	difference() {
		cube( [ lcd_pcb_w+2*wall,  lcd_pcb_l+plug_l+2*wall,
			lcd_assembly_t+wall ] ) ;
		union() {
			translate( [ wall, wall, wall ] )
				cube( [lcd_pcb_w, lcd_pcb_l+plug_l,
					lcd_assembly_t+1 ]) ;
			translate( [ wall+(lcd_pcb_w-lcd_w)/2,
				wall+(lcd_pcb_l-lcd_l)/2, -1 ] )
				cube( [lcd_w, lcd_l, 50 ] ) ;
		}
	}
	// attachment tabs for the base
	for ( y_offset = [ 10,
			   -2.5+wall+(lcd_pcb_l+plug_l)/2,
			   lcd_pcb_l+plug_l-10-5 ] ) 
	translate( [ 0, y_offset, lcd_assembly_t+wall ] )
	difference() {
		cube( [ lcd_pcb_w+2*wall, 5, 3 ] ) ;
		hull() {
			translate( [ wall, -1, -0.1 ] )
				cube( [ lcd_pcb_w, 7, 0.1 ] ) ;
			translate( [ wall+1, -1, 3 ] )
				cube( [ lcd_pcb_w-2, 7, 0.1 ] ) ;
		}
	}
}

module lcd_base()
{
	center_w = wall+lcd_pcb_w / 2 ;
	center_l = wall+(lcd_pcb_l+plug_l) / 2 ;
	difference() {
		union() {
			cube( [ 2*wall+lcd_pcb_w,
				2*wall+lcd_pcb_l+plug_l,
				wall ] ) ;
			translate( [ center_w-10, center_l-10, 1 ] )
				cube( [ 20, 20, 20 ] ) ;
		}
		union() {
			translate( [ center_w-8, center_l-8, -1 ] )
					cube( [ 16, 16, 50 ] ) ;
			// i holes for the attachment tabs
			for ( y_offset = [ 9, 
					   -3.5+wall+(lcd_pcb_l+plug_l)/2,
					   lcd_pcb_l+plug_l-16 ] ) 
			translate( [ -0.5, y_offset, -1 ] ) {
				cube( [ wall+1.5, 7, 4 ] ) ;
				translate( [ wall+lcd_pcb_w, 0, 0 ] )
				cube( [ wall+2.6, 7, 4 ] ) ;
			}
			// hole for the attachment screw
			translate( [ 21.7, 1, 11.0 ] )
			rotate( [ -90, 0, 0 ] ) 
			cylinder( 100, d=3.5, $fn=50 ) ;
		}
	}
}

module lcd_knockout()
{
	center_w = wall+lcd_pcb_w / 2 ;
	center_l = wall+(lcd_pcb_l+plug_l) / 2 ;
	cube( [ lcd_pcb_w+2*wall+2,  lcd_pcb_l+plug_l+2*wall+2,
		lcd_assembly_t+2*wall+2 ] ) ;
	translate( [ center_w-10.5, center_l-10.5, 22] )
			cube( [ 21, 21, 21 ] ) ;
}

lcd_housing() ;
//translate( [ 0, 0, 22 ] ) lcd_base() ;
translate( [ lcd_pcb_w + 10, 0, 0 ] ) lcd_base() ;
//translate( [ 2*lcd_pcb_w + 10, 0, 0 ] ) lcd_knockout() ;


// nenad me fecit
