// The main body of the hand-held tachometer. Builds either the left side,
// or the right side, or the battery compartment slide cover.

// By Nenad Rijavec
// Feel free to use, share, modify, etc. as you see fit.

use <plib/nut_holes.scad>
use <plib/makehollow.scad>
use <components/9v_housing.scad>
use <components/trigger.scad>
use <components/slide_cover.scad>
use <components/nano_holder.scad>
use <components/pot_wheel.scad>
use <constructs/dpdt_switch.scad>
use <lcd_housing.scad>
use <sensor_pod.scad>

// only one thing is built at a time. If multiple items are selected, the
// first one is built.
do_build = 1 ; // activates the build stanza
bld_left = 0 ;
bld_right = 1 ;
bld_slide_cover = 0 ;
trigger_h = 12 ;
handle_w = 49 ;
handle_l = 160 ;
handle_delta = 60 ;
handle_h = 40 ;

b_off_x = -56.0 ;
b_off_y = 35 ;
switch_x = -6;
switch_y = 62 ;
nano_x = 1 ;
nano_y = -3 ;
body_x = 70 ;
body_y = 46 ;
body_z = 32 ;

module trigger_knockout( )
{
	cube( [ 17, 64, trigger_h+7] ) ;
	translate( [ -10, 4, 0 ] )
	cube( [ 20, 56, trigger_h+7 ] ) ;
}


module handle_full()
{
	minkowski() {
		intersection() {
			scale( [ handle_w, handle_l, handle_h ] )
				sphere( d=1, $fn=100);
			cube( [ handle_w,
					handle_l-handle_delta,
					handle_h - 8 ], center=true ) ;
		}
		sphere( d=3, $fn=100 ) ;
	}
}

module handle_shell( shell_t )
{
	difference( ) {
		handle_full() ;
		minkowski() {
			intersection() {
				scale( [ handle_w-4, handle_l-4, handle_h-4 ] )
					sphere( d=1, $fn=100);
				cube( [ handle_w-4,
					handle_l-handle_delta-4,
					handle_h - 12 ], center=true ) ;
			}
			sphere( d=3, $fn=100 ) ;
		}
	}
}

module handle( shell_t )
{
	difference(){
		union() {
			handle_shell( shell_t ) ; 
			// intersect the inner structures with the
			// solid handle body to trim any bits and pieces
			// that stick out
			intersection() {
			union() {
				// trigger housing receiver
				//   grid outside, thin plate to accept
				translate( [ -12.5, -43.0, -handle_h/2 ])
				for ( i=[0:11:66] )
					translate( [ 0, i, 0 ] )
						cube( [ 5, 0.3, handle_h-8 ] ) ;
				translate( [ -12.5, -43.0, -handle_h/2+4 ])
				for ( j=[0, 5 ] )
					translate( [ j, 0, 0 ] )
						cube( [ 0.3, 66, handle_h ] ) ;
				translate( [ -19.5, -43.0, -trigger_h/2-5 ] )
				cube( [ 18, 20, trigger_h+10 ] ) ;
				translate( [ -20.5, -23.0, -trigger_h/2-5 ] )
				cube( [ 13, 40, trigger_h+10] ) ;
				translate( [ -20.5, 17.0, -trigger_h/2-5 ] )
				cube( [ 18.5, 7, trigger_h+10 ] ) ;
				// grid to support nano holder
				translate([ nano_x, nano_y-45, -handle_h/2+4 ])
				for ( i=[1:10:50] )
					translate( [ 0, i, 0 ] )
					cube( [ 11, 0.3, handle_h - 8] ) ;
				translate( [nano_x, nano_y-45, -handle_h/2+4 ])
				for ( i=[0.1, 5.7, 7.0, 10.7] )
					translate( [ i, 0, 0 ] )
					cube( [ 0.3, 45, handle_h - 8] ) ;
				}
				handle_full() ;
			}
		}
		union() {
			translate( [ -18.5, -42, -trigger_h/2-4 ] )
				trigger_knockout() ;
			translate( [ -15.5, 12.0, -6-trigger_h/2 ] )
				cylinder( trigger_h+12, d=2, $fn=100 ) ;
			// nano holder and USB aperture
			translate( [ nano_x, nano_y, 12 ] ) rotate( [ -90,
			0, -90 ] )
			union() {
			//translate( [ 2, 2, 6 ] ) nano_mockup() ;
				hull()nano_holder( 2, -6 ) ;
			}
		}
	}
	// Finish trigger receiver box, must be out of diff so it remains
	// whole. The back plane needs a gap for trigger wiring
	translate( [ -2.0, -43.0, -handle_h/2+4 ] )
	difference() {
		cube( [ 1, 67, handle_h-8 ] ) ;
		translate( [ -1, 2, 4 ] )
		cube( [ 3, 15, handle_h-16 ] ) ;
	}
	translate( [ -20, 45.0, -trigger_h/2-2 ] )
	cube( [ 18, 1, trigger_h-4 ] ) ;
	//translate([ -18.0, -41.0, -trigger_h/2-3]) trigger_housing(trigger_h);
	// nano holder
	translate( [ nano_x, nano_y, 12 ] ) rotate( [ -90, 0, -90 ] )
	union() { // translate( [ 2, 2, 6 ] ) nano_mockup() ;
		nano_holder( 2, -6 ) ;
	}
}

// if makehole, just punches all the holes - screw, head, nut
// else makes casings without holes
module one_screw( makehole, x, y, len, thread_len, full_casing )
{
	cyl_d = 6 ;
	extra_h = 50 ;
	translate( [ x, y, 0 ] )
	if ( makehole ) union() {
		cylinder( len, d=4.5, center=true, $fn=50 ) ;
		translate( [ 0, 0, thread_len/2 ] )
		cylinder( (len-thread_len)/2+extra_h, d=8, $fn=50 ) ;
		translate( [ 0, 0, -len/2-extra_h] )
			nut_m3( extra_h+ (len-thread_len)/2 ) ;
	} else if ( full_casing ) union() {
		cylinder( len, d=cyl_d, center=true, $fn=50 ) ;
		translate( [ 0, 0, -len/2 ] ) 
		cylinder( (len-thread_len)/2+1, d=9, $fn=50 ) ;
		translate( [ 0, 0, thread_len/2-1 ] ) 
		cylinder( (len-thread_len)/2+1, d=9, $fn=50 ) ;
	} else union() {
		//cylinder( len, d=cyl_d, center=true, $fn=50 ) ;
		translate( [ 0, 0, -len/2-1 ] ) 
		cylinder( (len-thread_len)/2+2, d=9, $fn=50 ) ;
		translate( [ 0, 0, thread_len/2-2 ] ) 
		cylinder( (len-thread_len)/2+2, d=9, $fn=50 ) ;
	}
}

module closure_screws( makeholes )
{
	// each screw entry is x, y, length, thread length, full casing
	screws = [
		[ -15, 69, 32, 24, 0 ],
		[ -55, 72, 32, 24, 1 ],
		[ -115, 85, 32, 24, 0 ],
		[ 24, -40.5, 32.0, 24, 1 ],
		[ -15, 25.0, 32, 24, 1 ]
	] ;

	for ( i = [0:len(screws)-1] ) {
		one_screw( makeholes, screws[i][0], screws[i][1],
				screws[i][2], screws[i][3], screws[i][4] ) ;
	}
}

module upper_body_solid()
{
	d = 3 ;
	points1 = [ 
	[ 22, 0 - 20 ],
	[ 45, 0 ],
	[ body_x-d, -d ],
	[ body_x-d, body_y-d ],
	[ 20, body_y-d ],
	[ 10, 15+body_y-d ],
	[ -70, 15+body_y-d ],
	[ -70, -5+body_y-d ],
	[ -35, -5+body_y-d ],
	[ 0, 5 ],
	] ;
	
	translate( [ b_off_x, b_off_y, -body_z/2 ] )
		linear_extrude( body_z ) { polygon( points1 ) ; }
}

module body()
{
	shell_t = 1 ;
	difference() {
		union() {
			difference() {
				rotate( [ 0, 0, 30 ] ) handle( shell_t ) ; 
				upper_body_solid() ;
			}
			difference() {
				union() {
					makehollow( shell_t, 3)
						upper_body_solid() ;
					//indicator led holder
					translate([ -12, b_off_y+body_y-2, 0 ])
						rotate ( [ 90, 0, 0 ] )
						cylinder( 5, d=8, $fn=100 ) ;
					translate([-12, b_off_y+body_y-8,
								-body_z/2+1])
						cube( [ 6, 5, body_z-1 ] ) ;
				}
				union() {
					rotate( [ 0, 0, 30 ] ) handle_full() ;
					translate( [ -45, 109, -42 ] )
					rotate( [ 90, 0, -50 ] )
						lcd_knockout() ;
				}
			}
			// pot holder
			translate( [ -110, 77, -body_z/2+2 ] ) 
			cube( [ 35, 5, body_z-1 ] ) ;
//following to verify the LCD housinh fits
//translate( [ -45.0, 108.5, -42 ] )
//rotate( [ 90, 0, -50 ] ) 
//union() {
	//lcd_housing() ;
	//translate( [ 0, 0, 20 ] ) lcd_base() ;
//}
		}
		union() {
			// 9v cover knockout
			translate( [ 9, 33.0, -19 ] )
				cube( [ 10, box_h()+5, box_w() ] ) ;
			// switch & holder konckout
			translate( [ switch_x, switch_y, -14 ] )
			rotate( [ 90, 0, 90 ] )
			union() {
				hull() switch_holder( 6, 1, 2, 0 ) ;
				translate( [ 4, 2, 15 ] ) cube( [7,24, 90 ]) ;

			}
			// ir led and photodiode holder
			translate( [ -131, 80, 0 ] )
				rotate( [ 90, 0, 90 ])
				sensor_pod_knockout( 8 ) ;
			// pot wheel cutout
			translate( [ -94, 89, -3.5 ] ) 
				cylinder( 7, d=33, $fn=100 ) ;
			//indicator led cutout
			translate( [ -12, b_off_y+body_y+5, 0 ] )
				rotate ( [ 90, 0, 0 ] )
				cylinder( 15, d=4, $fn=100 ) ;
			translate( [ -12, b_off_y+body_y-3, 0 ] )
				rotate ( [ 90, 0, 0 ] )
				cylinder( 2, d=7, $fn=100 ) ;
			// closure screw holes in body
			closure_screws( 1 ) ;
		}
	}
	// closure screw tubes
	difference() {
		closure_screws( 0 ) ;
		union() {
			closure_screws( 1 ) ;
			// must also fit LCD holder
			translate( [ -45, 109, -42 ] )
			rotate( [ 90, 0, -50 ] ) lcd_knockout() ;
		}
	}
	// 9v holder - support plates
	translate( [ -41, 33.5, -16 ] )
	cube( [ box_l()-9, box_h()+4, 2 ] ) ;
	translate( [ -44, 33.5, 14 ] )
	cube( [ box_l()-9, box_h()+4, 2 ] ) ;
	translate( [ -43.5, 33.5, -16 ] )
	cube( [ 7, box_h()+4, 3 ] ) ;
	translate( [ -44, 33.5, 13 ] )
	cube( [ 7, box_h()+4, 3 ] ) ;
	// 9v holder 
	difference() {
		translate( [ -16, 45.5, -4 ] )
		rotate( [ 90, 0, 0 ] )
		rotate( [ 0, 0, -90 ] )
		translate( [ -6-box_w()/2, -2-box_l()/2, -1-box_h()/2 ] ) 
			9v_box_outline() ;
		// 9v cover knockout
	translate( [ 9, 32.5, -16 ] )
	cube( [ 10, box_h()+6, box_w() ] ) ;
	}
	// 9v cover frame
	translate( [ 8.5, 32.0, -17.5 ] ) 
	rotate( [ 0, 90, 0 ] )
	rotate( [ 0, 0, 90 ] )
		slide_cover_base( 19, 26, 3 ) ;
	// switch holder 
	translate( [ switch_x, switch_y-1, -14 ] )
	cube( [ 17, 1, 28 ] ) ;
	translate( [ switch_x, switch_y, -14 ] ) rotate( [ 90, 0, 90 ] )
		switch_holder( 6, 1, 2, 0 ) ;
}


module body_left()
{
	intersection() {
		body() ;
		translate( [ -200, -200, 0 ] ) 
			cube( [ 400, 400, 100 ] ) ;
	}
}

module body_right()
{
	intersection() {
		body() ;
		translate( [ -200, -200, -100 ] ) 
			//cube( [ 150, 400, 100 ] ) ;
			cube( [ 400, 400, 100 ] ) ;
	}
}

// done with defining the objects. Build stanzas follow.

if ( do_build ) {
	if ( bld_left )
		translate( [ -45, 0, 18 ] )
		rotate( [ 0, 180, 0 ] )
		body_left() ;
	else if ( bld_right )
		translate( [ 45, 0, handle_h/2 ] )
		body_right() ;
	else if ( bld_slide_cover )
		slide_cover( 18, 29.5, 3 ) ;
} else {

// various debug and fit-test stanzas, uncomment as desired
//intersection() { 
	//union() {
		//body_grid() ;
		body_right() ;
		//body() ;
//translate( [ 80, 0, 0 ] ) rotate( [ 0, 180, 0 ] ) body_left() ;
		//translate( [ -26, -30, -9 ] ) trigger_housing( 12 ) ;
	//} 
//translate( [-100, -135, -50 ] ) cube( [ 200, 120, 100 ] ) ;
//}

//translate( [ -45.0, 108.5, -42 ] )
//rotate( [ 90, 0, -50 ] )
//union() {
	//lcd_housing() ;
	//translate( [ 0, 0, 20 ] ) lcd_base() ;
//}

//translate( [ -122.5, 80, 0 ] ) rotate( [ -90, 0, 90 ]) ir_led_housing() ;
//translate( [ -89, 89, 0 ] ) pot_wheel() ;
}
	// nano holder
	//translate( [ nano_x, nano_y, 12 ] ) rotate( [ -90, 0, -60 ] )
	//union() { translate( [ 2, 2, 6 ] ) nano_mockup() ;
		//nano_holder( 2, -6 ) ;
	//}

//nenad me fecit
